/********************************************************************
* Copyright (C) 2003-2008 Texas Instruments Incorporated.
* All Rights Reserved
*********************************************************************
* file: cslr_cor_hdr.h
*
* Brief: This file contains the Register Description for cor_hdr
*
*********************************************************************/
#ifndef _CSLR_BCP_COR_HDR_H_
#define _CSLR_BCP_COR_HDR_H_

#include <ti/csl/cslr.h>

#include <ti/csl/tistdtypes.h>


/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 WORD0; /* COR local header */
    volatile Uint32 WORD1; /* PUCCH Config */
    volatile Uint32 WORD2; /* DESPREAD Config0 */
    volatile Uint32 WORD3; /* DESPREAD Config1 */
    volatile Uint32 WORD4; /* DESPREAD Config2 */
    volatile Uint32 WORD5; /* DESPREAD Config3 */
    volatile Uint32 WORD6; /* DESPREAD Config4 */
    volatile Uint32 WORD7; /* DESPREAD Config5 */
} CSL_Cor_hdrRegs;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* Word 0 */




#define CSL_COR_HDR_WORD0_DESPREAD_FLAG_CPLX_MASK (0x00020000u)
#define CSL_COR_HDR_WORD0_DESPREAD_FLAG_CPLX_SHIFT (0x00000011u)
#define CSL_COR_HDR_WORD0_DESPREAD_FLAG_CPLX_RESETVAL (0x00000000u)

#define CSL_COR_HDR_WORD0_PUCCH_DESPREAD_SEL_MASK (0x00010000u)
#define CSL_COR_HDR_WORD0_PUCCH_DESPREAD_SEL_SHIFT (0x00000010u)
#define CSL_COR_HDR_WORD0_PUCCH_DESPREAD_SEL_RESETVAL (0x00000000u)


#define CSL_COR_HDR_WORD0_MOD_ID_MASK    (0x00000F00u)
#define CSL_COR_HDR_WORD0_MOD_ID_SHIFT   (0x00000008u)
#define CSL_COR_HDR_WORD0_MOD_ID_RESETVAL (0x00000000u)


#define CSL_COR_HDR_WORD0_LOCAL_HDR_LEN_MASK (0x0000003Fu)
#define CSL_COR_HDR_WORD0_LOCAL_HDR_LEN_SHIFT (0x00000000u)
#define CSL_COR_HDR_WORD0_LOCAL_HDR_LEN_RESETVAL (0x00000000u)

#define CSL_COR_HDR_WORD0_RESETVAL       (0x00000000u)

/* Word 1 */


#define CSL_COR_HDR_WORD1_PUCCH_MODE_MASK (0x10000000u)
#define CSL_COR_HDR_WORD1_PUCCH_MODE_SHIFT (0x0000001Cu)
#define CSL_COR_HDR_WORD1_PUCCH_MODE_RESETVAL (0x00000000u)

#define CSL_COR_HDR_WORD1_PUCCH_NR_MASK  (0x0F000000u)
#define CSL_COR_HDR_WORD1_PUCCH_NR_SHIFT (0x00000018u)
#define CSL_COR_HDR_WORD1_PUCCH_NR_RESETVAL (0x00000000u)

#define CSL_COR_HDR_WORD1_PUCCH_SCR_SEQ_MASK (0x00FFFFF0u)
#define CSL_COR_HDR_WORD1_PUCCH_SCR_SEQ_SHIFT (0x00000004u)
#define CSL_COR_HDR_WORD1_PUCCH_SCR_SEQ_RESETVAL (0x00000000u)

#define CSL_COR_HDR_WORD1_PUCCH_A_MASK   (0x0000000Fu)
#define CSL_COR_HDR_WORD1_PUCCH_A_SHIFT  (0x00000000u)
#define CSL_COR_HDR_WORD1_PUCCH_A_RESETVAL (0x00000000u)

#define CSL_COR_HDR_WORD1_RESETVAL       (0x00000000u)

/* Word 2 */


#define CSL_COR_HDR_WORD2_SF_RATIO_MASK  (0x00070000u)
#define CSL_COR_HDR_WORD2_SF_RATIO_SHIFT (0x00000010u)
#define CSL_COR_HDR_WORD2_SF_RATIO_RESETVAL (0x00000000u)

#define CSL_COR_HDR_WORD2_DESPREAD_LENGTH_MASK (0x0000FFFFu)
#define CSL_COR_HDR_WORD2_DESPREAD_LENGTH_SHIFT (0x00000000u)
#define CSL_COR_HDR_WORD2_DESPREAD_LENGTH_RESETVAL (0x00000000u)

#define CSL_COR_HDR_WORD2_RESETVAL       (0x00000000u)

/* Word 3 */


#define CSL_COR_HDR_WORD3_SF_RATIO_MASK  (0x00070000u)
#define CSL_COR_HDR_WORD3_SF_RATIO_SHIFT (0x00000010u)
#define CSL_COR_HDR_WORD3_SF_RATIO_RESETVAL (0x00000000u)

#define CSL_COR_HDR_WORD3_DESPREAD_LENGTH_MASK (0x0000FFFFu)
#define CSL_COR_HDR_WORD3_DESPREAD_LENGTH_SHIFT (0x00000000u)
#define CSL_COR_HDR_WORD3_DESPREAD_LENGTH_RESETVAL (0x00000000u)

#define CSL_COR_HDR_WORD3_RESETVAL       (0x00000000u)

/* Word 4 */


#define CSL_COR_HDR_WORD4_SF_RATIO_MASK  (0x00070000u)
#define CSL_COR_HDR_WORD4_SF_RATIO_SHIFT (0x00000010u)
#define CSL_COR_HDR_WORD4_SF_RATIO_RESETVAL (0x00000000u)

#define CSL_COR_HDR_WORD4_DESPREAD_LENGTH_MASK (0x0000FFFFu)
#define CSL_COR_HDR_WORD4_DESPREAD_LENGTH_SHIFT (0x00000000u)
#define CSL_COR_HDR_WORD4_DESPREAD_LENGTH_RESETVAL (0x00000000u)

#define CSL_COR_HDR_WORD4_RESETVAL       (0x00000000u)

/* Word 5 */


#define CSL_COR_HDR_WORD5_SF_RATIO_MASK  (0x00070000u)
#define CSL_COR_HDR_WORD5_SF_RATIO_SHIFT (0x00000010u)
#define CSL_COR_HDR_WORD5_SF_RATIO_RESETVAL (0x00000000u)

#define CSL_COR_HDR_WORD5_DESPREAD_LENGTH_MASK (0x0000FFFFu)
#define CSL_COR_HDR_WORD5_DESPREAD_LENGTH_SHIFT (0x00000000u)
#define CSL_COR_HDR_WORD5_DESPREAD_LENGTH_RESETVAL (0x00000000u)

#define CSL_COR_HDR_WORD5_RESETVAL       (0x00000000u)

/* Word 6 */


#define CSL_COR_HDR_WORD6_SF_RATIO_MASK  (0x00070000u)
#define CSL_COR_HDR_WORD6_SF_RATIO_SHIFT (0x00000010u)
#define CSL_COR_HDR_WORD6_SF_RATIO_RESETVAL (0x00000000u)

#define CSL_COR_HDR_WORD6_DESPREAD_LENGTH_MASK (0x0000FFFFu)
#define CSL_COR_HDR_WORD6_DESPREAD_LENGTH_SHIFT (0x00000000u)
#define CSL_COR_HDR_WORD6_DESPREAD_LENGTH_RESETVAL (0x00000000u)

#define CSL_COR_HDR_WORD6_RESETVAL       (0x00000000u)

/* Word 7 */


#define CSL_COR_HDR_WORD7_SF_RATIO_MASK  (0x00070000u)
#define CSL_COR_HDR_WORD7_SF_RATIO_SHIFT (0x00000010u)
#define CSL_COR_HDR_WORD7_SF_RATIO_RESETVAL (0x00000000u)

#define CSL_COR_HDR_WORD7_DESPREAD_LENGTH_MASK (0x0000FFFFu)
#define CSL_COR_HDR_WORD7_DESPREAD_LENGTH_SHIFT (0x00000000u)
#define CSL_COR_HDR_WORD7_DESPREAD_LENGTH_RESETVAL (0x00000000u)

#define CSL_COR_HDR_WORD7_RESETVAL       (0x00000000u)

#endif
