/*
 *
 * Copyright (C) 2010-2013 Texas Instruments Incorporated - http://www.ti.com/ 
 * 
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/




#include "tfutest.h"

#define SYS_CLEAN_VERIFY TRUE
#define SETUP_VERIFY     FALSE

Void topLevelTest (UArg a0, UArg a1);

/* The exit code is a global. This is used so
 * the clock function can terminate the program with
 * the proper exit code */
int exitCode;


/* Creates a single task - the top level task. This is a low priority task that
 * spawns the individual tests */
extern cregister volatile unsigned int TSCL;
Void main ()
{
	Task_Params tparams;
#if defined (PARTNO_C6678) || defined (PARTNO_C6670) || defined (PARTNO_C6657)
#else
    uint32_t                    bootMode;
#endif
	/* The only initial task is the top level test */
	Task_Params_init (&tparams);
	tparams.instance->name = "Top Level Test";
	tparams.priority      = 1;
	
	Task_create (topLevelTest, &tparams, NULL);
	
	/* Start the cycle counter */
	TSCL = 1;
#if defined (PARTNO_C6678) || defined (PARTNO_C6670) || defined (PARTNO_C6657)
#else
    if (autodetectLogic == TRUE)
    {
       bootMode = CSL_BootCfgGetBootMode();
#if !defined (PARTNO_C6614)
       bootMode = (bootMode & 7);
#endif

       if (bootMode == 0)
    	  no_bootMode = TRUE;
       else
    	   no_bootMode = FALSE;
    }
    else {
    	no_bootMode = TRUE;
    }
#endif
	BIOS_start ();
}


Void clk1Fxn (UArg a0)
{
	BIOS_exit (exitCode);
}

/* Initialize the test framework and launch the individual tests */
Void topLevelTest (UArg a0, UArg a1)
{
	Task_Params tparams;
	Task_Handle thandle;
	Task_Stat   tstat;
	
	Clock_Handle clkh;       
    Clock_Params clkParams;
	uint32_t     coreId = CSL_chipReadDNUM();	
	int i;
	
	
	/* For some reason some printfs are lost unless there is a delay between System_flush
	 * and System_exit, so delay is forced */	
	Clock_Params_init(&clkParams);
    clkParams.period    = 0;
    clkParams.startFlag = FALSE;
    clkh = Clock_create(clk1Fxn, 1, &clkParams, NULL);
    
    /* Initialize the PA, PA cpdma, QM and CPPI. Each test will use
     * the same framework */
    if (coreId == 0)
    {
        System_printf ("\n\n ------- TF Unit Test Starting ---------\n");

    	if (setupTestFramework ())  {
        	System_printf ("topLevelTest (%s:%d): setupTestFramework returned error, exiting\n", __FILE__, __LINE__);
        	System_flush ();
        	exitCode = -1;
        	Clock_start(clkh);
        	Task_exit ();
        }
        
        /* Make sure the setup matches what is expected */
        if (verifyTestFramework(SETUP_VERIFY))  {
        	System_printf ("topLevelTest (%s:%d): verifyTestFramework returned error after initial framework setup, exiting\n", __FILE__, __LINE__);
        	System_flush();
        	exitCode = -1;
        	Clock_start(clkh);
        	Task_exit ();
        }
    }
    else
    {
        if (setupTestFramework_slave ())  {
        	System_printf ("topLevelTest (%s:%d): setupTestFramework_slave returned error, exiting\n", __FILE__, __LINE__);
        	System_flush ();
        	exitCode = -1;
        	Clock_start(clkh);
        	Task_exit ();
        }
    }
     
    /* Configure task parameters common to all test tasks */
    Task_Params_init (&tparams);
    tparams.priority = 2;
    tparams.arg0     = (UArg) &unitTestFramework;

	System_flush();
	
	/* Run the tests */
	for (i = 0; (tfTestList[i].testFunction != NULL); i++ )  {
		
		tparams.arg1 = (UArg)&tfTestList[i];
		tparams.instance->name = tfTestList[i].name;

		thandle = Task_create (tfTestList[i].testFunction, &tparams, NULL);
		
		/* The test task will terminate upon completion. Verify that the
		 * task has completed in case the task itself uses multiple tasks
		 * that all wind up idle for a while. */
		do  {
			Task_stat (thandle, &tstat);
		} while (tstat.mode != Task_Mode_TERMINATED);
		
		Task_delete (&thandle);

	} 

	/* Clean and verify the test framework on Master DSP core */
	if (coreId == 0) {

	    /* Do a quick check of the test framework */
	    if (verifyTestFramework (SYS_CLEAN_VERIFY))  {
			System_printf ("topLevelTest (%s:%d): verifyTestFramework returned error after test %s. Exiting.\n", __FILE__, __LINE__, tfTestList[i].name);
			exitCode = -1;
			System_flush ();
			Clock_start(clkh);
	    }

		if (clearTestFramework() ) {
			System_printf ("\n\n ------- TF Unit Test Clean Failed ---------\n");
		}

		System_printf ("\n\n ------- TF Unit Test Complete ---------\n");
		System_flush();
	}
	else {
		if (clearTestFramework_slave() ) {
			System_printf ("\n\n ------- TF Unit Test Clean Failed ---------\n");
		}
	}

	Clock_start(clkh);
	
	Task_exit();
}




